@@ -12,12 +12,16 @@ function parallel::aggregate_test_results() {
   local total_snapshot=0
 
   for script_dir in "$temp_dir_parallel_test_suite"/*; do
-    if ! compgen -G "$script_dir"/*.result > /dev/null; then
+    shopt -s nullglob
+    local result_files=("$script_dir"/*.result)
+    shopt -u nullglob
+
+    if [ ${#result_files[@]} -eq 0 ]; then
       printf "%sNo tests found%s" "$_COLOR_SKIPPED" "$_COLOR_DEFAULT"
       continue
     fi
 
-    for result_file in "$script_dir"/*.result; do
+    for result_file in "${result_files[@]}"; do
       local result_line
       result_line=$(tail -n 1 "$result_file")
 
